package com.zhyc.module.feed.service;

import java.util.List;
import com.zhyc.module.feed.domain.SgFeedStatistic;

/**
 * 饲喂量统计Service接口
 * 
 * @author HashMap
 * @date 2025-08-23
 */
public interface ISgFeedStatisticService 
{
    /**
     * 查询饲喂量统计
     * 
     * @param id 饲喂量统计主键
     * @return 饲喂量统计
     */
    SgFeedStatistic selectSgFeedStatisticById(String id);

    /**
     * 查询饲喂量统计列表
     * 
     * @param sgFeedStatistic 饲喂量统计
     * @return 饲喂量统计集合
     */
    List<SgFeedStatistic> selectSgFeedStatisticList(SgFeedStatistic sgFeedStatistic);

    /**
     * 新增饲喂量统计
     * 
     * @param sgFeedStatistic 饲喂量统计
     * @return 结果
     */
    int insertSgFeedStatistic(SgFeedStatistic sgFeedStatistic);

    /**
     * 修改饲喂量统计
     * 
     * @param sgFeedStatistic 饲喂量统计
     * @return 结果
     */
    int updateSgFeedStatistic(SgFeedStatistic sgFeedStatistic);

    /**
     * 批量删除饲喂量统计
     * 
     * @param ids 需要删除的饲喂量统计主键集合
     * @return 结果
     */
    int deleteSgFeedStatisticByIds(String[] ids);

    /**
     * 删除饲喂量统计信息
     * 
     * @param id 饲喂量统计主键
     * @return 结果
     */
    int deleteSgFeedStatisticById(String id);

    void getInitSgFeedStatistic(SgFeedStatistic sgFeedStatistic);


}
